"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.ai.tuning.v1.tuning_error_pb2
import yandex.cloud.ai.tuning.v1.tuning_optimizers_pb2
import yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2
import yandex.cloud.ai.tuning.v1.tuning_task_pb2
import yandex.cloud.ai.tuning.v1.tuning_types_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListTuningsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Required field. ID of the folder to list tunings in."""
    page_size: builtins.int
    """Maximum number of tuning tasks to return per page."""
    page_token: builtins.str
    """Token to retrieve the next page of results."""
    status: yandex.cloud.ai.tuning.v1.tuning_task_pb2.TuningTask.Status.ValueType
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        status: yandex.cloud.ai.tuning.v1.tuning_task_pb2.TuningTask.Status.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token", "status", b"status"]) -> None: ...

global___ListTuningsRequest = ListTuningsRequest

@typing.final
class ListTuningsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TUNING_TASKS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token to retrieve the next page of results."""
    @property
    def tuning_tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.tuning.v1.tuning_task_pb2.TuningTask]:
        """List of tuning tasks in the specified folder."""

    def __init__(
        self,
        *,
        tuning_tasks: collections.abc.Iterable[yandex.cloud.ai.tuning.v1.tuning_task_pb2.TuningTask] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "tuning_tasks", b"tuning_tasks"]) -> None: ...

global___ListTuningsResponse = ListTuningsResponse

@typing.final
class DescribeTuningRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TUNING_TASK_ID_FIELD_NUMBER: builtins.int
    tuning_task_id: builtins.str
    def __init__(
        self,
        *,
        tuning_task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tuning_task_id", b"tuning_task_id"]) -> None: ...

global___DescribeTuningRequest = DescribeTuningRequest

@typing.final
class DescribeTuningResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TUNING_TASK_FIELD_NUMBER: builtins.int
    @property
    def tuning_task(self) -> yandex.cloud.ai.tuning.v1.tuning_task_pb2.TuningTask: ...
    def __init__(
        self,
        *,
        tuning_task: yandex.cloud.ai.tuning.v1.tuning_task_pb2.TuningTask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["tuning_task", b"tuning_task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["tuning_task", b"tuning_task"]) -> None: ...

global___DescribeTuningResponse = DescribeTuningResponse

@typing.final
class CancelTuningRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TUNING_TASK_ID_FIELD_NUMBER: builtins.int
    tuning_task_id: builtins.str
    def __init__(
        self,
        *,
        tuning_task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tuning_task_id", b"tuning_task_id"]) -> None: ...

global___CancelTuningRequest = CancelTuningRequest

@typing.final
class CancelTuningResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TUNING_TASK_ID_FIELD_NUMBER: builtins.int
    tuning_task_id: builtins.str
    def __init__(
        self,
        *,
        tuning_task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tuning_task_id", b"tuning_task_id"]) -> None: ...

global___CancelTuningResponse = CancelTuningResponse

@typing.final
class TuningResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TUNING_TASK_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TARGET_MODEL_URI_FIELD_NUMBER: builtins.int
    tuning_task_id: builtins.str
    status: yandex.cloud.ai.tuning.v1.tuning_task_pb2.TuningTask.Status.ValueType
    target_model_uri: builtins.str
    def __init__(
        self,
        *,
        tuning_task_id: builtins.str = ...,
        status: yandex.cloud.ai.tuning.v1.tuning_task_pb2.TuningTask.Status.ValueType = ...,
        target_model_uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "target_model_uri", b"target_model_uri", "tuning_task_id", b"tuning_task_id"]) -> None: ...

global___TuningResponse = TuningResponse

@typing.final
class TuningMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TUNING_TASK_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TOTAL_STEPS_FIELD_NUMBER: builtins.int
    CURRENT_STEP_FIELD_NUMBER: builtins.int
    tuning_task_id: builtins.str
    status: yandex.cloud.ai.tuning.v1.tuning_task_pb2.TuningTask.Status.ValueType
    total_steps: builtins.int
    current_step: builtins.int
    def __init__(
        self,
        *,
        tuning_task_id: builtins.str = ...,
        status: yandex.cloud.ai.tuning.v1.tuning_task_pb2.TuningTask.Status.ValueType = ...,
        total_steps: builtins.int = ...,
        current_step: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["current_step", b"current_step", "status", b"status", "total_steps", b"total_steps", "tuning_task_id", b"tuning_task_id"]) -> None: ...

global___TuningMetadata = TuningMetadata

@typing.final
class TuningRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class WeightedDataset(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DATASET_ID_FIELD_NUMBER: builtins.int
        WEIGHT_FIELD_NUMBER: builtins.int
        dataset_id: builtins.str
        weight: builtins.float
        def __init__(
            self,
            *,
            dataset_id: builtins.str = ...,
            weight: builtins.float = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["dataset_id", b"dataset_id", "weight", b"weight"]) -> None: ...

    BASE_MODEL_URI_FIELD_NUMBER: builtins.int
    TRAIN_DATASETS_FIELD_NUMBER: builtins.int
    VALIDATION_DATASETS_FIELD_NUMBER: builtins.int
    VALIDATION_DATASET_FIELD_NUMBER: builtins.int
    TEST_DATASETS_FIELD_NUMBER: builtins.int
    TEXT_TO_TEXT_COMPLETION_FIELD_NUMBER: builtins.int
    TEXT_CLASSIFICATION_MULTILABEL_FIELD_NUMBER: builtins.int
    TEXT_CLASSIFICATION_MULTICLASS_FIELD_NUMBER: builtins.int
    TEXT_EMBEDDING_PAIR_PARAMS_FIELD_NUMBER: builtins.int
    TEXT_EMBEDDING_TRIPLET_PARAMS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    base_model_uri: builtins.str
    """Format like a `gpt://{folder_id}/yandex-gpt/latest`"""
    name: builtins.str
    description: builtins.str
    @property
    def train_datasets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TuningRequest.WeightedDataset]: ...
    @property
    def validation_datasets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TuningRequest.WeightedDataset]: ...
    @property
    def validation_dataset(self) -> global___TuningRequest.WeightedDataset: ...
    @property
    def test_datasets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TuningRequest.WeightedDataset]: ...
    @property
    def text_to_text_completion(self) -> global___TextToTextCompletionTuningParams: ...
    @property
    def text_classification_multilabel(self) -> global___TextClassificationMultilabelParams: ...
    @property
    def text_classification_multiclass(self) -> global___TextClassificationMulticlassParams: ...
    @property
    def text_embedding_pair_params(self) -> global___TextEmbeddingPairParams:
        """TextEmbeddingPairParams  is unimplemented"""

    @property
    def text_embedding_triplet_params(self) -> global___TextEmbeddingTripletParams:
        """TextEmbeddingTripletParams  is unimplemented"""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        base_model_uri: builtins.str = ...,
        train_datasets: collections.abc.Iterable[global___TuningRequest.WeightedDataset] | None = ...,
        validation_datasets: collections.abc.Iterable[global___TuningRequest.WeightedDataset] | None = ...,
        validation_dataset: global___TuningRequest.WeightedDataset | None = ...,
        test_datasets: collections.abc.Iterable[global___TuningRequest.WeightedDataset] | None = ...,
        text_to_text_completion: global___TextToTextCompletionTuningParams | None = ...,
        text_classification_multilabel: global___TextClassificationMultilabelParams | None = ...,
        text_classification_multiclass: global___TextClassificationMulticlassParams | None = ...,
        text_embedding_pair_params: global___TextEmbeddingPairParams | None = ...,
        text_embedding_triplet_params: global___TextEmbeddingTripletParams | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["text_classification_multiclass", b"text_classification_multiclass", "text_classification_multilabel", b"text_classification_multilabel", "text_embedding_pair_params", b"text_embedding_pair_params", "text_embedding_triplet_params", b"text_embedding_triplet_params", "text_to_text_completion", b"text_to_text_completion", "tuning_params", b"tuning_params", "validation_dataset", b"validation_dataset"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["base_model_uri", b"base_model_uri", "description", b"description", "labels", b"labels", "name", b"name", "test_datasets", b"test_datasets", "text_classification_multiclass", b"text_classification_multiclass", "text_classification_multilabel", b"text_classification_multilabel", "text_embedding_pair_params", b"text_embedding_pair_params", "text_embedding_triplet_params", b"text_embedding_triplet_params", "text_to_text_completion", b"text_to_text_completion", "train_datasets", b"train_datasets", "tuning_params", b"tuning_params", "validation_dataset", b"validation_dataset", "validation_datasets", b"validation_datasets"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["tuning_params", b"tuning_params"]) -> typing.Literal["text_to_text_completion", "text_classification_multilabel", "text_classification_multiclass", "text_embedding_pair_params", "text_embedding_triplet_params"] | None: ...

global___TuningRequest = TuningRequest

@typing.final
class TextToTextCompletionTuningParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Scheduler(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LINEAR_FIELD_NUMBER: builtins.int
        CONSTANT_FIELD_NUMBER: builtins.int
        COSINE_FIELD_NUMBER: builtins.int
        WARMUP_RATIO_FIELD_NUMBER: builtins.int
        warmup_ratio: builtins.float
        @property
        def linear(self) -> yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerLinear: ...
        @property
        def constant(self) -> yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerConstant: ...
        @property
        def cosine(self) -> yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerCosine: ...
        def __init__(
            self,
            *,
            linear: yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerLinear | None = ...,
            constant: yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerConstant | None = ...,
            cosine: yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerCosine | None = ...,
            warmup_ratio: builtins.float = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["constant", b"constant", "cosine", b"cosine", "linear", b"linear", "type", b"type"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["constant", b"constant", "cosine", b"cosine", "linear", b"linear", "type", b"type", "warmup_ratio", b"warmup_ratio"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["linear", "constant", "cosine"] | None: ...

    @typing.final
    class Optimizer(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ADAMW_FIELD_NUMBER: builtins.int
        @property
        def adamw(self) -> yandex.cloud.ai.tuning.v1.tuning_optimizers_pb2.OptimizerAdamw: ...
        def __init__(
            self,
            *,
            adamw: yandex.cloud.ai.tuning.v1.tuning_optimizers_pb2.OptimizerAdamw | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["adamw", b"adamw", "type", b"type"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["adamw", b"adamw", "type", b"type"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["adamw"] | None: ...

    SEED_FIELD_NUMBER: builtins.int
    LR_FIELD_NUMBER: builtins.int
    N_SAMPLES_FIELD_NUMBER: builtins.int
    ADDITIONAL_ARGUMENTS_FIELD_NUMBER: builtins.int
    LORA_FIELD_NUMBER: builtins.int
    PROMPT_TUNE_FIELD_NUMBER: builtins.int
    SCHEDULER_FIELD_NUMBER: builtins.int
    OPTIMIZER_FIELD_NUMBER: builtins.int
    seed: builtins.int
    lr: builtins.float
    n_samples: builtins.int
    additional_arguments: builtins.str
    @property
    def lora(self) -> yandex.cloud.ai.tuning.v1.tuning_types_pb2.TuningTypeLora: ...
    @property
    def prompt_tune(self) -> yandex.cloud.ai.tuning.v1.tuning_types_pb2.TuningTypePromptTune: ...
    @property
    def scheduler(self) -> global___TextToTextCompletionTuningParams.Scheduler: ...
    @property
    def optimizer(self) -> global___TextToTextCompletionTuningParams.Optimizer: ...
    def __init__(
        self,
        *,
        seed: builtins.int = ...,
        lr: builtins.float = ...,
        n_samples: builtins.int = ...,
        additional_arguments: builtins.str = ...,
        lora: yandex.cloud.ai.tuning.v1.tuning_types_pb2.TuningTypeLora | None = ...,
        prompt_tune: yandex.cloud.ai.tuning.v1.tuning_types_pb2.TuningTypePromptTune | None = ...,
        scheduler: global___TextToTextCompletionTuningParams.Scheduler | None = ...,
        optimizer: global___TextToTextCompletionTuningParams.Optimizer | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["lora", b"lora", "optimizer", b"optimizer", "prompt_tune", b"prompt_tune", "scheduler", b"scheduler", "tuning_type", b"tuning_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["additional_arguments", b"additional_arguments", "lora", b"lora", "lr", b"lr", "n_samples", b"n_samples", "optimizer", b"optimizer", "prompt_tune", b"prompt_tune", "scheduler", b"scheduler", "seed", b"seed", "tuning_type", b"tuning_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["tuning_type", b"tuning_type"]) -> typing.Literal["lora", "prompt_tune"] | None: ...

global___TextToTextCompletionTuningParams = TextToTextCompletionTuningParams

@typing.final
class TextClassificationMultilabelParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Scheduler(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LINEAR_FIELD_NUMBER: builtins.int
        CONSTANT_FIELD_NUMBER: builtins.int
        COSINE_FIELD_NUMBER: builtins.int
        WARMUP_RATIO_FIELD_NUMBER: builtins.int
        warmup_ratio: builtins.float
        @property
        def linear(self) -> yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerLinear: ...
        @property
        def constant(self) -> yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerConstant: ...
        @property
        def cosine(self) -> yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerCosine: ...
        def __init__(
            self,
            *,
            linear: yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerLinear | None = ...,
            constant: yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerConstant | None = ...,
            cosine: yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerCosine | None = ...,
            warmup_ratio: builtins.float = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["constant", b"constant", "cosine", b"cosine", "linear", b"linear", "type", b"type"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["constant", b"constant", "cosine", b"cosine", "linear", b"linear", "type", b"type", "warmup_ratio", b"warmup_ratio"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["linear", "constant", "cosine"] | None: ...

    @typing.final
    class Optimizer(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ADAMW_FIELD_NUMBER: builtins.int
        @property
        def adamw(self) -> yandex.cloud.ai.tuning.v1.tuning_optimizers_pb2.OptimizerAdamw: ...
        def __init__(
            self,
            *,
            adamw: yandex.cloud.ai.tuning.v1.tuning_optimizers_pb2.OptimizerAdamw | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["adamw", b"adamw", "type", b"type"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["adamw", b"adamw", "type", b"type"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["adamw"] | None: ...

    SEED_FIELD_NUMBER: builtins.int
    LR_FIELD_NUMBER: builtins.int
    N_SAMPLES_FIELD_NUMBER: builtins.int
    ADDITIONAL_ARGUMENTS_FIELD_NUMBER: builtins.int
    LORA_FIELD_NUMBER: builtins.int
    PROMPT_TUNE_FIELD_NUMBER: builtins.int
    SCHEDULER_FIELD_NUMBER: builtins.int
    OPTIMIZER_FIELD_NUMBER: builtins.int
    seed: builtins.int
    lr: builtins.float
    n_samples: builtins.int
    additional_arguments: builtins.str
    @property
    def lora(self) -> yandex.cloud.ai.tuning.v1.tuning_types_pb2.TuningTypeLora: ...
    @property
    def prompt_tune(self) -> yandex.cloud.ai.tuning.v1.tuning_types_pb2.TuningTypePromptTune: ...
    @property
    def scheduler(self) -> global___TextClassificationMultilabelParams.Scheduler: ...
    @property
    def optimizer(self) -> global___TextClassificationMultilabelParams.Optimizer: ...
    def __init__(
        self,
        *,
        seed: builtins.int = ...,
        lr: builtins.float = ...,
        n_samples: builtins.int = ...,
        additional_arguments: builtins.str = ...,
        lora: yandex.cloud.ai.tuning.v1.tuning_types_pb2.TuningTypeLora | None = ...,
        prompt_tune: yandex.cloud.ai.tuning.v1.tuning_types_pb2.TuningTypePromptTune | None = ...,
        scheduler: global___TextClassificationMultilabelParams.Scheduler | None = ...,
        optimizer: global___TextClassificationMultilabelParams.Optimizer | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["lora", b"lora", "optimizer", b"optimizer", "prompt_tune", b"prompt_tune", "scheduler", b"scheduler", "tuning_type", b"tuning_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["additional_arguments", b"additional_arguments", "lora", b"lora", "lr", b"lr", "n_samples", b"n_samples", "optimizer", b"optimizer", "prompt_tune", b"prompt_tune", "scheduler", b"scheduler", "seed", b"seed", "tuning_type", b"tuning_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["tuning_type", b"tuning_type"]) -> typing.Literal["lora", "prompt_tune"] | None: ...

global___TextClassificationMultilabelParams = TextClassificationMultilabelParams

@typing.final
class TextClassificationMulticlassParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Scheduler(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LINEAR_FIELD_NUMBER: builtins.int
        CONSTANT_FIELD_NUMBER: builtins.int
        COSINE_FIELD_NUMBER: builtins.int
        WARMUP_RATIO_FIELD_NUMBER: builtins.int
        warmup_ratio: builtins.float
        @property
        def linear(self) -> yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerLinear: ...
        @property
        def constant(self) -> yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerConstant: ...
        @property
        def cosine(self) -> yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerCosine: ...
        def __init__(
            self,
            *,
            linear: yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerLinear | None = ...,
            constant: yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerConstant | None = ...,
            cosine: yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerCosine | None = ...,
            warmup_ratio: builtins.float = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["constant", b"constant", "cosine", b"cosine", "linear", b"linear", "type", b"type"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["constant", b"constant", "cosine", b"cosine", "linear", b"linear", "type", b"type", "warmup_ratio", b"warmup_ratio"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["linear", "constant", "cosine"] | None: ...

    @typing.final
    class Optimizer(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ADAMW_FIELD_NUMBER: builtins.int
        @property
        def adamw(self) -> yandex.cloud.ai.tuning.v1.tuning_optimizers_pb2.OptimizerAdamw: ...
        def __init__(
            self,
            *,
            adamw: yandex.cloud.ai.tuning.v1.tuning_optimizers_pb2.OptimizerAdamw | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["adamw", b"adamw", "type", b"type"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["adamw", b"adamw", "type", b"type"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["adamw"] | None: ...

    SEED_FIELD_NUMBER: builtins.int
    LR_FIELD_NUMBER: builtins.int
    N_SAMPLES_FIELD_NUMBER: builtins.int
    ADDITIONAL_ARGUMENTS_FIELD_NUMBER: builtins.int
    LORA_FIELD_NUMBER: builtins.int
    PROMPT_TUNE_FIELD_NUMBER: builtins.int
    SCHEDULER_FIELD_NUMBER: builtins.int
    OPTIMIZER_FIELD_NUMBER: builtins.int
    seed: builtins.int
    lr: builtins.float
    n_samples: builtins.int
    additional_arguments: builtins.str
    @property
    def lora(self) -> yandex.cloud.ai.tuning.v1.tuning_types_pb2.TuningTypeLora: ...
    @property
    def prompt_tune(self) -> yandex.cloud.ai.tuning.v1.tuning_types_pb2.TuningTypePromptTune: ...
    @property
    def scheduler(self) -> global___TextClassificationMulticlassParams.Scheduler: ...
    @property
    def optimizer(self) -> global___TextClassificationMulticlassParams.Optimizer: ...
    def __init__(
        self,
        *,
        seed: builtins.int = ...,
        lr: builtins.float = ...,
        n_samples: builtins.int = ...,
        additional_arguments: builtins.str = ...,
        lora: yandex.cloud.ai.tuning.v1.tuning_types_pb2.TuningTypeLora | None = ...,
        prompt_tune: yandex.cloud.ai.tuning.v1.tuning_types_pb2.TuningTypePromptTune | None = ...,
        scheduler: global___TextClassificationMulticlassParams.Scheduler | None = ...,
        optimizer: global___TextClassificationMulticlassParams.Optimizer | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["lora", b"lora", "optimizer", b"optimizer", "prompt_tune", b"prompt_tune", "scheduler", b"scheduler", "tuning_type", b"tuning_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["additional_arguments", b"additional_arguments", "lora", b"lora", "lr", b"lr", "n_samples", b"n_samples", "optimizer", b"optimizer", "prompt_tune", b"prompt_tune", "scheduler", b"scheduler", "seed", b"seed", "tuning_type", b"tuning_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["tuning_type", b"tuning_type"]) -> typing.Literal["lora", "prompt_tune"] | None: ...

global___TextClassificationMulticlassParams = TextClassificationMulticlassParams

@typing.final
class TextEmbeddingPairParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Scheduler(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LINEAR_FIELD_NUMBER: builtins.int
        CONSTANT_FIELD_NUMBER: builtins.int
        COSINE_FIELD_NUMBER: builtins.int
        WARMUP_RATIO_FIELD_NUMBER: builtins.int
        warmup_ratio: builtins.float
        @property
        def linear(self) -> yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerLinear: ...
        @property
        def constant(self) -> yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerConstant: ...
        @property
        def cosine(self) -> yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerCosine: ...
        def __init__(
            self,
            *,
            linear: yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerLinear | None = ...,
            constant: yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerConstant | None = ...,
            cosine: yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerCosine | None = ...,
            warmup_ratio: builtins.float = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["constant", b"constant", "cosine", b"cosine", "linear", b"linear", "optional_warmup_ratio", b"optional_warmup_ratio", "type", b"type", "warmup_ratio", b"warmup_ratio"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["constant", b"constant", "cosine", b"cosine", "linear", b"linear", "optional_warmup_ratio", b"optional_warmup_ratio", "type", b"type", "warmup_ratio", b"warmup_ratio"]) -> None: ...
        @typing.overload
        def WhichOneof(self, oneof_group: typing.Literal["optional_warmup_ratio", b"optional_warmup_ratio"]) -> typing.Literal["warmup_ratio"] | None: ...
        @typing.overload
        def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["linear", "constant", "cosine"] | None: ...

    @typing.final
    class Optimizer(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ADAMW_FIELD_NUMBER: builtins.int
        @property
        def adamw(self) -> yandex.cloud.ai.tuning.v1.tuning_optimizers_pb2.OptimizerAdamw: ...
        def __init__(
            self,
            *,
            adamw: yandex.cloud.ai.tuning.v1.tuning_optimizers_pb2.OptimizerAdamw | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["adamw", b"adamw", "type", b"type"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["adamw", b"adamw", "type", b"type"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["adamw"] | None: ...

    SEED_FIELD_NUMBER: builtins.int
    LR_FIELD_NUMBER: builtins.int
    N_SAMPLES_FIELD_NUMBER: builtins.int
    ADDITIONAL_ARGUMENTS_FIELD_NUMBER: builtins.int
    EMBEDDING_DIMS_FIELD_NUMBER: builtins.int
    LORA_FIELD_NUMBER: builtins.int
    PROMPT_TUNE_FIELD_NUMBER: builtins.int
    SCHEDULER_FIELD_NUMBER: builtins.int
    OPTIMIZER_FIELD_NUMBER: builtins.int
    seed: builtins.int
    lr: builtins.float
    n_samples: builtins.int
    additional_arguments: builtins.str
    @property
    def embedding_dims(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    @property
    def lora(self) -> yandex.cloud.ai.tuning.v1.tuning_types_pb2.TuningTypeLora: ...
    @property
    def prompt_tune(self) -> yandex.cloud.ai.tuning.v1.tuning_types_pb2.TuningTypePromptTune: ...
    @property
    def scheduler(self) -> global___TextEmbeddingPairParams.Scheduler: ...
    @property
    def optimizer(self) -> global___TextEmbeddingPairParams.Optimizer: ...
    def __init__(
        self,
        *,
        seed: builtins.int = ...,
        lr: builtins.float = ...,
        n_samples: builtins.int = ...,
        additional_arguments: builtins.str = ...,
        embedding_dims: collections.abc.Iterable[builtins.int] | None = ...,
        lora: yandex.cloud.ai.tuning.v1.tuning_types_pb2.TuningTypeLora | None = ...,
        prompt_tune: yandex.cloud.ai.tuning.v1.tuning_types_pb2.TuningTypePromptTune | None = ...,
        scheduler: global___TextEmbeddingPairParams.Scheduler | None = ...,
        optimizer: global___TextEmbeddingPairParams.Optimizer | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["lora", b"lora", "optimizer", b"optimizer", "prompt_tune", b"prompt_tune", "scheduler", b"scheduler", "tuning_type", b"tuning_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["additional_arguments", b"additional_arguments", "embedding_dims", b"embedding_dims", "lora", b"lora", "lr", b"lr", "n_samples", b"n_samples", "optimizer", b"optimizer", "prompt_tune", b"prompt_tune", "scheduler", b"scheduler", "seed", b"seed", "tuning_type", b"tuning_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["tuning_type", b"tuning_type"]) -> typing.Literal["lora", "prompt_tune"] | None: ...

global___TextEmbeddingPairParams = TextEmbeddingPairParams

@typing.final
class TextEmbeddingTripletParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Scheduler(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LINEAR_FIELD_NUMBER: builtins.int
        CONSTANT_FIELD_NUMBER: builtins.int
        COSINE_FIELD_NUMBER: builtins.int
        WARMUP_RATIO_FIELD_NUMBER: builtins.int
        warmup_ratio: builtins.float
        @property
        def linear(self) -> yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerLinear: ...
        @property
        def constant(self) -> yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerConstant: ...
        @property
        def cosine(self) -> yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerCosine: ...
        def __init__(
            self,
            *,
            linear: yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerLinear | None = ...,
            constant: yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerConstant | None = ...,
            cosine: yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2.SchedulerCosine | None = ...,
            warmup_ratio: builtins.float = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["constant", b"constant", "cosine", b"cosine", "linear", b"linear", "optional_warmup_ratio", b"optional_warmup_ratio", "type", b"type", "warmup_ratio", b"warmup_ratio"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["constant", b"constant", "cosine", b"cosine", "linear", b"linear", "optional_warmup_ratio", b"optional_warmup_ratio", "type", b"type", "warmup_ratio", b"warmup_ratio"]) -> None: ...
        @typing.overload
        def WhichOneof(self, oneof_group: typing.Literal["optional_warmup_ratio", b"optional_warmup_ratio"]) -> typing.Literal["warmup_ratio"] | None: ...
        @typing.overload
        def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["linear", "constant", "cosine"] | None: ...

    @typing.final
    class Optimizer(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ADAMW_FIELD_NUMBER: builtins.int
        @property
        def adamw(self) -> yandex.cloud.ai.tuning.v1.tuning_optimizers_pb2.OptimizerAdamw: ...
        def __init__(
            self,
            *,
            adamw: yandex.cloud.ai.tuning.v1.tuning_optimizers_pb2.OptimizerAdamw | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["adamw", b"adamw", "type", b"type"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["adamw", b"adamw", "type", b"type"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["adamw"] | None: ...

    SEED_FIELD_NUMBER: builtins.int
    LR_FIELD_NUMBER: builtins.int
    N_SAMPLES_FIELD_NUMBER: builtins.int
    ADDITIONAL_ARGUMENTS_FIELD_NUMBER: builtins.int
    EMBEDDING_DIMS_FIELD_NUMBER: builtins.int
    LORA_FIELD_NUMBER: builtins.int
    PROMPT_TUNE_FIELD_NUMBER: builtins.int
    SCHEDULER_FIELD_NUMBER: builtins.int
    OPTIMIZER_FIELD_NUMBER: builtins.int
    seed: builtins.int
    lr: builtins.float
    n_samples: builtins.int
    additional_arguments: builtins.str
    @property
    def embedding_dims(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    @property
    def lora(self) -> yandex.cloud.ai.tuning.v1.tuning_types_pb2.TuningTypeLora: ...
    @property
    def prompt_tune(self) -> yandex.cloud.ai.tuning.v1.tuning_types_pb2.TuningTypePromptTune: ...
    @property
    def scheduler(self) -> global___TextEmbeddingTripletParams.Scheduler: ...
    @property
    def optimizer(self) -> global___TextEmbeddingTripletParams.Optimizer: ...
    def __init__(
        self,
        *,
        seed: builtins.int = ...,
        lr: builtins.float = ...,
        n_samples: builtins.int = ...,
        additional_arguments: builtins.str = ...,
        embedding_dims: collections.abc.Iterable[builtins.int] | None = ...,
        lora: yandex.cloud.ai.tuning.v1.tuning_types_pb2.TuningTypeLora | None = ...,
        prompt_tune: yandex.cloud.ai.tuning.v1.tuning_types_pb2.TuningTypePromptTune | None = ...,
        scheduler: global___TextEmbeddingTripletParams.Scheduler | None = ...,
        optimizer: global___TextEmbeddingTripletParams.Optimizer | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["lora", b"lora", "optimizer", b"optimizer", "prompt_tune", b"prompt_tune", "scheduler", b"scheduler", "tuning_type", b"tuning_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["additional_arguments", b"additional_arguments", "embedding_dims", b"embedding_dims", "lora", b"lora", "lr", b"lr", "n_samples", b"n_samples", "optimizer", b"optimizer", "prompt_tune", b"prompt_tune", "scheduler", b"scheduler", "seed", b"seed", "tuning_type", b"tuning_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["tuning_type", b"tuning_type"]) -> typing.Literal["lora", "prompt_tune"] | None: ...

global___TextEmbeddingTripletParams = TextEmbeddingTripletParams

@typing.final
class GetMetricsUrlRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_ID_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["task_id", b"task_id"]) -> None: ...

global___GetMetricsUrlRequest = GetMetricsUrlRequest

@typing.final
class GetMetricsUrlResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_URL_FIELD_NUMBER: builtins.int
    load_url: builtins.str
    def __init__(
        self,
        *,
        load_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["load_url", b"load_url"]) -> None: ...

global___GetMetricsUrlResponse = GetMetricsUrlResponse

@typing.final
class GetOptionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_ID_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["task_id", b"task_id"]) -> None: ...

global___GetOptionsRequest = GetOptionsRequest

@typing.final
class GetOptionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_ID_FIELD_NUMBER: builtins.int
    BASE_MODEL_URI_FIELD_NUMBER: builtins.int
    TRAIN_DATASETS_FIELD_NUMBER: builtins.int
    VALIDATION_DATASETS_FIELD_NUMBER: builtins.int
    TEXT_TO_TEXT_COMPLETION_FIELD_NUMBER: builtins.int
    TEXT_CLASSIFICATION_MULTILABEL_FIELD_NUMBER: builtins.int
    TEXT_CLASSIFICATION_MULTICLASS_FIELD_NUMBER: builtins.int
    TEXT_EMBEDDING_PAIR_PARAMS_FIELD_NUMBER: builtins.int
    TEXT_EMBEDDING_TRIPLET_PARAMS_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    base_model_uri: builtins.str
    @property
    def train_datasets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TuningRequest.WeightedDataset]: ...
    @property
    def validation_datasets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TuningRequest.WeightedDataset]: ...
    @property
    def text_to_text_completion(self) -> global___TextToTextCompletionTuningParams: ...
    @property
    def text_classification_multilabel(self) -> global___TextClassificationMultilabelParams: ...
    @property
    def text_classification_multiclass(self) -> global___TextClassificationMulticlassParams: ...
    @property
    def text_embedding_pair_params(self) -> global___TextEmbeddingPairParams: ...
    @property
    def text_embedding_triplet_params(self) -> global___TextEmbeddingTripletParams: ...
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
        base_model_uri: builtins.str = ...,
        train_datasets: collections.abc.Iterable[global___TuningRequest.WeightedDataset] | None = ...,
        validation_datasets: collections.abc.Iterable[global___TuningRequest.WeightedDataset] | None = ...,
        text_to_text_completion: global___TextToTextCompletionTuningParams | None = ...,
        text_classification_multilabel: global___TextClassificationMultilabelParams | None = ...,
        text_classification_multiclass: global___TextClassificationMulticlassParams | None = ...,
        text_embedding_pair_params: global___TextEmbeddingPairParams | None = ...,
        text_embedding_triplet_params: global___TextEmbeddingTripletParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["text_classification_multiclass", b"text_classification_multiclass", "text_classification_multilabel", b"text_classification_multilabel", "text_embedding_pair_params", b"text_embedding_pair_params", "text_embedding_triplet_params", b"text_embedding_triplet_params", "text_to_text_completion", b"text_to_text_completion", "tuning_params", b"tuning_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["base_model_uri", b"base_model_uri", "task_id", b"task_id", "text_classification_multiclass", b"text_classification_multiclass", "text_classification_multilabel", b"text_classification_multilabel", "text_embedding_pair_params", b"text_embedding_pair_params", "text_embedding_triplet_params", b"text_embedding_triplet_params", "text_to_text_completion", b"text_to_text_completion", "train_datasets", b"train_datasets", "tuning_params", b"tuning_params", "validation_datasets", b"validation_datasets"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["tuning_params", b"tuning_params"]) -> typing.Literal["text_to_text_completion", "text_classification_multilabel", "text_classification_multiclass", "text_embedding_pair_params", "text_embedding_triplet_params"] | None: ...

global___GetOptionsResponse = GetOptionsResponse

@typing.final
class ListErrorsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TUNING_TASK_ID_FIELD_NUMBER: builtins.int
    tuning_task_id: builtins.str
    def __init__(
        self,
        *,
        tuning_task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tuning_task_id", b"tuning_task_id"]) -> None: ...

global___ListErrorsRequest = ListErrorsRequest

@typing.final
class ListErrorsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TUNING_ERROR_FIELD_NUMBER: builtins.int
    @property
    def tuning_error(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.tuning.v1.tuning_error_pb2.TuningError]: ...
    def __init__(
        self,
        *,
        tuning_error: collections.abc.Iterable[yandex.cloud.ai.tuning.v1.tuning_error_pb2.TuningError] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tuning_error", b"tuning_error"]) -> None: ...

global___ListErrorsResponse = ListErrorsResponse

@typing.final
class CreateTuningDraftRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    BASE_MODEL_URI_FIELD_NUMBER: builtins.int
    TRAIN_DATASETS_FIELD_NUMBER: builtins.int
    VALIDATION_DATASETS_FIELD_NUMBER: builtins.int
    TEXT_TO_TEXT_COMPLETION_FIELD_NUMBER: builtins.int
    TEXT_CLASSIFICATION_MULTILABEL_FIELD_NUMBER: builtins.int
    TEXT_CLASSIFICATION_MULTICLASS_FIELD_NUMBER: builtins.int
    TEXT_EMBEDDING_PAIR_PARAMS_FIELD_NUMBER: builtins.int
    TEXT_EMBEDDING_TRIPLET_PARAMS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    base_model_uri: builtins.str
    name: builtins.str
    description: builtins.str
    @property
    def train_datasets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TuningRequest.WeightedDataset]: ...
    @property
    def validation_datasets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TuningRequest.WeightedDataset]: ...
    @property
    def text_to_text_completion(self) -> global___TextToTextCompletionTuningParams: ...
    @property
    def text_classification_multilabel(self) -> global___TextClassificationMultilabelParams: ...
    @property
    def text_classification_multiclass(self) -> global___TextClassificationMulticlassParams: ...
    @property
    def text_embedding_pair_params(self) -> global___TextEmbeddingPairParams: ...
    @property
    def text_embedding_triplet_params(self) -> global___TextEmbeddingTripletParams: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        base_model_uri: builtins.str = ...,
        train_datasets: collections.abc.Iterable[global___TuningRequest.WeightedDataset] | None = ...,
        validation_datasets: collections.abc.Iterable[global___TuningRequest.WeightedDataset] | None = ...,
        text_to_text_completion: global___TextToTextCompletionTuningParams | None = ...,
        text_classification_multilabel: global___TextClassificationMultilabelParams | None = ...,
        text_classification_multiclass: global___TextClassificationMulticlassParams | None = ...,
        text_embedding_pair_params: global___TextEmbeddingPairParams | None = ...,
        text_embedding_triplet_params: global___TextEmbeddingTripletParams | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["text_classification_multiclass", b"text_classification_multiclass", "text_classification_multilabel", b"text_classification_multilabel", "text_embedding_pair_params", b"text_embedding_pair_params", "text_embedding_triplet_params", b"text_embedding_triplet_params", "text_to_text_completion", b"text_to_text_completion", "tuning_params", b"tuning_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["base_model_uri", b"base_model_uri", "description", b"description", "labels", b"labels", "name", b"name", "text_classification_multiclass", b"text_classification_multiclass", "text_classification_multilabel", b"text_classification_multilabel", "text_embedding_pair_params", b"text_embedding_pair_params", "text_embedding_triplet_params", b"text_embedding_triplet_params", "text_to_text_completion", b"text_to_text_completion", "train_datasets", b"train_datasets", "tuning_params", b"tuning_params", "validation_datasets", b"validation_datasets"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["tuning_params", b"tuning_params"]) -> typing.Literal["text_to_text_completion", "text_classification_multilabel", "text_classification_multiclass", "text_embedding_pair_params", "text_embedding_triplet_params"] | None: ...

global___CreateTuningDraftRequest = CreateTuningDraftRequest

@typing.final
class CreateTuningDraftResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TUNING_TASK_ID_FIELD_NUMBER: builtins.int
    tuning_task_id: builtins.str
    def __init__(
        self,
        *,
        tuning_task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tuning_task_id", b"tuning_task_id"]) -> None: ...

global___CreateTuningDraftResponse = CreateTuningDraftResponse

@typing.final
class UpdateTuningDraftRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    TUNING_TASK_ID_FIELD_NUMBER: builtins.int
    BASE_MODEL_URI_FIELD_NUMBER: builtins.int
    TRAIN_DATASETS_FIELD_NUMBER: builtins.int
    VALIDATION_DATASETS_FIELD_NUMBER: builtins.int
    TEXT_TO_TEXT_COMPLETION_FIELD_NUMBER: builtins.int
    TEXT_CLASSIFICATION_MULTILABEL_FIELD_NUMBER: builtins.int
    TEXT_CLASSIFICATION_MULTICLASS_FIELD_NUMBER: builtins.int
    TEXT_EMBEDDING_PAIR_PARAMS_FIELD_NUMBER: builtins.int
    TEXT_EMBEDDING_TRIPLET_PARAMS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    tuning_task_id: builtins.str
    base_model_uri: builtins.str
    name: builtins.str
    description: builtins.str
    @property
    def train_datasets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TuningRequest.WeightedDataset]: ...
    @property
    def validation_datasets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TuningRequest.WeightedDataset]: ...
    @property
    def text_to_text_completion(self) -> global___TextToTextCompletionTuningParams: ...
    @property
    def text_classification_multilabel(self) -> global___TextClassificationMultilabelParams: ...
    @property
    def text_classification_multiclass(self) -> global___TextClassificationMulticlassParams: ...
    @property
    def text_embedding_pair_params(self) -> global___TextEmbeddingPairParams: ...
    @property
    def text_embedding_triplet_params(self) -> global___TextEmbeddingTripletParams: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        tuning_task_id: builtins.str = ...,
        base_model_uri: builtins.str = ...,
        train_datasets: collections.abc.Iterable[global___TuningRequest.WeightedDataset] | None = ...,
        validation_datasets: collections.abc.Iterable[global___TuningRequest.WeightedDataset] | None = ...,
        text_to_text_completion: global___TextToTextCompletionTuningParams | None = ...,
        text_classification_multilabel: global___TextClassificationMultilabelParams | None = ...,
        text_classification_multiclass: global___TextClassificationMulticlassParams | None = ...,
        text_embedding_pair_params: global___TextEmbeddingPairParams | None = ...,
        text_embedding_triplet_params: global___TextEmbeddingTripletParams | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["text_classification_multiclass", b"text_classification_multiclass", "text_classification_multilabel", b"text_classification_multilabel", "text_embedding_pair_params", b"text_embedding_pair_params", "text_embedding_triplet_params", b"text_embedding_triplet_params", "text_to_text_completion", b"text_to_text_completion", "tuning_params", b"tuning_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["base_model_uri", b"base_model_uri", "description", b"description", "labels", b"labels", "name", b"name", "text_classification_multiclass", b"text_classification_multiclass", "text_classification_multilabel", b"text_classification_multilabel", "text_embedding_pair_params", b"text_embedding_pair_params", "text_embedding_triplet_params", b"text_embedding_triplet_params", "text_to_text_completion", b"text_to_text_completion", "train_datasets", b"train_datasets", "tuning_params", b"tuning_params", "tuning_task_id", b"tuning_task_id", "validation_datasets", b"validation_datasets"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["tuning_params", b"tuning_params"]) -> typing.Literal["text_to_text_completion", "text_classification_multilabel", "text_classification_multiclass", "text_embedding_pair_params", "text_embedding_triplet_params"] | None: ...

global___UpdateTuningDraftRequest = UpdateTuningDraftRequest

@typing.final
class UpdateTuningDraftResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TUNING_TASK_ID_FIELD_NUMBER: builtins.int
    tuning_task_id: builtins.str
    def __init__(
        self,
        *,
        tuning_task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tuning_task_id", b"tuning_task_id"]) -> None: ...

global___UpdateTuningDraftResponse = UpdateTuningDraftResponse

@typing.final
class DeleteTuningDraftRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TUNING_TASK_ID_FIELD_NUMBER: builtins.int
    tuning_task_id: builtins.str
    def __init__(
        self,
        *,
        tuning_task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tuning_task_id", b"tuning_task_id"]) -> None: ...

global___DeleteTuningDraftRequest = DeleteTuningDraftRequest

@typing.final
class DeleteTuningDraftResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TUNING_TASK_ID_FIELD_NUMBER: builtins.int
    tuning_task_id: builtins.str
    def __init__(
        self,
        *,
        tuning_task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tuning_task_id", b"tuning_task_id"]) -> None: ...

global___DeleteTuningDraftResponse = DeleteTuningDraftResponse

@typing.final
class TuneDraftRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TUNING_TASK_ID_FIELD_NUMBER: builtins.int
    tuning_task_id: builtins.str
    def __init__(
        self,
        *,
        tuning_task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tuning_task_id", b"tuning_task_id"]) -> None: ...

global___TuneDraftRequest = TuneDraftRequest

@typing.final
class ArchiveTuningRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TUNING_TASK_ID_FIELD_NUMBER: builtins.int
    tuning_task_id: builtins.str
    def __init__(
        self,
        *,
        tuning_task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tuning_task_id", b"tuning_task_id"]) -> None: ...

global___ArchiveTuningRequest = ArchiveTuningRequest

@typing.final
class ArchiveTuningMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ArchiveTuningMetadata = ArchiveTuningMetadata

@typing.final
class ArchiveTuningResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TUNING_TASK_ID_FIELD_NUMBER: builtins.int
    tuning_task_id: builtins.str
    def __init__(
        self,
        *,
        tuning_task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tuning_task_id", b"tuning_task_id"]) -> None: ...

global___ArchiveTuningResponse = ArchiveTuningResponse

@typing.final
class EnableBillingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TUNING_TASK_ID_FIELD_NUMBER: builtins.int
    tuning_task_id: builtins.str
    def __init__(
        self,
        *,
        tuning_task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tuning_task_id", b"tuning_task_id"]) -> None: ...

global___EnableBillingRequest = EnableBillingRequest

@typing.final
class EnableBillingResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TUNING_TASK_ID_FIELD_NUMBER: builtins.int
    tuning_task_id: builtins.str
    def __init__(
        self,
        *,
        tuning_task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tuning_task_id", b"tuning_task_id"]) -> None: ...

global___EnableBillingResponse = EnableBillingResponse

@typing.final
class EnableBillingMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___EnableBillingMetadata = EnableBillingMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class OAuthClient(google.protobuf.message.Message):
    """An OauthClient resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[OAuthClient._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: OAuthClient._Status.ValueType  # 0
        CREATING: OAuthClient._Status.ValueType  # 1
        """OAuth client is being created."""
        ACTIVE: OAuthClient._Status.ValueType  # 2
        """OAuth client is active."""
        DELETING: OAuthClient._Status.ValueType  # 3
        """OAuth client is being deleted."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: OAuthClient.Status.ValueType  # 0
    CREATING: OAuthClient.Status.ValueType  # 1
    """OAuth client is being created."""
    ACTIVE: OAuthClient.Status.ValueType  # 2
    """OAuth client is active."""
    DELETING: OAuthClient.Status.ValueType  # 3
    """OAuth client is being deleted."""

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    REDIRECT_URIS_FIELD_NUMBER: builtins.int
    SCOPES_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the oauth client."""
    name: builtins.str
    """Name for the oauth client."""
    folder_id: builtins.str
    """ID of the folder oauth client belongs to."""
    status: global___OAuthClient.Status.ValueType
    """Current status of the oauth client."""
    @property
    def redirect_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of redirect uries allowed for the oauth client."""

    @property
    def scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of oauth scopes requested by the oauth client."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        redirect_uris: collections.abc.Iterable[builtins.str] | None = ...,
        scopes: collections.abc.Iterable[builtins.str] | None = ...,
        folder_id: builtins.str = ...,
        status: global___OAuthClient.Status.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "id", b"id", "name", b"name", "redirect_uris", b"redirect_uris", "scopes", b"scopes", "status", b"status"]) -> None: ...

global___OAuthClient = OAuthClient



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.k8s.v1.resource_preset_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetResourcePresetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    resource_preset_id: builtins.str
    """Required. ID of the resource preset to return."""
    def __init__(
        self,
        *,
        resource_preset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_preset_id", b"resource_preset_id"]) -> None: ...

global___GetResourcePresetRequest = GetResourcePresetRequest

@typing.final
class ListResourcePresetsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListResourcePresetsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the [ListResourcePresetsResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListResourcePresetsRequest = ListResourcePresetsRequest

@typing.final
class ListResourcePresetsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PRESETS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListResourcePresetsRequest.page_size], use the [next_page_token] as the value
    for the [ListResourcePresetsRequest.page_token] parameter in the next list request. Each subsequent
    list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def resource_presets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.k8s.v1.resource_preset_pb2.ResourcePreset]:
        """List of ResourcePreset resources."""

    def __init__(
        self,
        *,
        resource_presets: collections.abc.Iterable[yandex.cloud.k8s.v1.resource_preset_pb2.ResourcePreset] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "resource_presets", b"resource_presets"]) -> None: ...

global___ListResourcePresetsResponse = ListResourcePresetsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/video/v1/style_preset_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/video/v1/style_preset_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.video.v1 import style_preset_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/video/v1/style_preset_service.proto\x12\x15yandex.cloud.video.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a(yandex/cloud/video/v1/style_preset.proto\">\n\x15GetStylePresetRequest\x12%\n\x0fstyle_preset_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xb8\x01\n\x17ListStylePresetsRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x1f\n\npage_token\x18\x65 \x01(\tB\x0b\x8a\xc8\x31\x07<=15000\x12\x1a\n\x08order_by\x18\x66 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1a\n\x06\x66ilter\x18g \x01(\tB\n\x8a\xc8\x31\x06<=1000J\x04\x08\x02\x10\x64\"t\n\x18ListStylePresetsResponse\x12\x39\n\rstyle_presets\x18\x01 \x03(\x0b\x32\".yandex.cloud.video.v1.StylePreset\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"\x9b\x07\n\x18\x43reateStylePresetRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\x05title\x18\x02 \x01(\tB\x1f\xe8\xc7\x31\x01\xf2\xc7\x31\x0f[a-zA-Z0-9-_ ]+\x8a\xc8\x31\x04<=50\x12\x37\n\x10\x62\x61\x63kground_color\x18\x03 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[#a-zA-Z0-9]+\x8a\xc8\x31\x04<=50\x12@\n\x19widget_text_color_primary\x18\x04 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[#a-zA-Z0-9]+\x8a\xc8\x31\x04<=50\x12\x42\n\x1bwidget_text_color_secondary\x18\x05 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[#a-zA-Z0-9]+\x8a\xc8\x31\x04<=50\x12:\n\x13widget_accent_color\x18\x06 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[#a-zA-Z0-9]+\x8a\xc8\x31\x04<=50\x12\"\n\x10widget_block_gap\x18\x07 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-10\x12\x43\n\x1cwidget_block_separator_color\x18\x08 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[#a-zA-Z0-9]+\x8a\xc8\x31\x04<=50\x12%\n\x14player_border_radius\x18\r \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12\x33\n\x0cplayer_color\x18\x0e \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[#a-zA-Z0-9]+\x8a\xc8\x31\x04<=50\x12N\n\'playlist_selected_item_background_color\x18\x0f \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[#a-zA-Z0-9]+\x8a\xc8\x31\x04<=50\x12,\n\x1bplaylist_item_border_radius\x18\x10 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12\"\n\x11playlist_item_gap\x18\x11 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12R\n\x11playlist_location\x18\x12 \x01(\x0e\x32\x31.yandex.cloud.video.v1.StylePreset.WidgetLocationB\x04\xe8\xc7\x31\x01\x12\x34\n\rright_widgets\x18\x0b \x03(\x0b\x32\x1d.yandex.cloud.video.v1.Widget\x12\x35\n\x0e\x62ottom_widgets\x18\x0c \x03(\x0b\x32\x1d.yandex.cloud.video.v1.WidgetJ\x04\x08\t\x10\nJ\x04\x08\n\x10\x0b\"4\n\x19\x43reateStylePresetMetadata\x12\x17\n\x0fstyle_preset_id\x18\x01 \x01(\t\"\xb5\x07\n\x18UpdateStylePresetRequest\x12%\n\x0fstyle_preset_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x34\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12*\n\x05title\x18\x03 \x01(\tB\x1b\xf2\xc7\x31\x0f[a-zA-Z0-9-_ ]*\x8a\xc8\x31\x04<=50\x12\x34\n\x10\x62\x61\x63kground_color\x18\x04 \x01(\tB\x1a\xf2\xc7\x31\x0e[#a-zA-Z0-9-]*\x8a\xc8\x31\x04<=50\x12=\n\x19widget_text_color_primary\x18\x05 \x01(\tB\x1a\xf2\xc7\x31\x0e[#a-zA-Z0-9-]*\x8a\xc8\x31\x04<=50\x12?\n\x1bwidget_text_color_secondary\x18\x06 \x01(\tB\x1a\xf2\xc7\x31\x0e[#a-zA-Z0-9-]*\x8a\xc8\x31\x04<=50\x12\x37\n\x13widget_accent_color\x18\x07 \x01(\tB\x1a\xf2\xc7\x31\x0e[#a-zA-Z0-9-]*\x8a\xc8\x31\x04<=50\x12\"\n\x10widget_block_gap\x18\x08 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-10\x12@\n\x1cwidget_block_separator_color\x18\t \x01(\tB\x1a\xf2\xc7\x31\x0e[#a-zA-Z0-9-]*\x8a\xc8\x31\x04<=50\x12%\n\x14player_border_radius\x18\x0e \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12/\n\x0cplayer_color\x18\x0f \x01(\tB\x19\xf2\xc7\x31\r[#a-zA-Z0-9]*\x8a\xc8\x31\x04<=50\x12J\n\'playlist_selected_item_background_color\x18\x10 \x01(\tB\x19\xf2\xc7\x31\r[#a-zA-Z0-9]*\x8a\xc8\x31\x04<=50\x12,\n\x1bplaylist_item_border_radius\x18\x11 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12\"\n\x11playlist_item_gap\x18\x12 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12L\n\x11playlist_location\x18\x13 \x01(\x0e\x32\x31.yandex.cloud.video.v1.StylePreset.WidgetLocation\x12\x34\n\rright_widgets\x18\x0c \x03(\x0b\x32\x1d.yandex.cloud.video.v1.Widget\x12\x35\n\x0e\x62ottom_widgets\x18\r \x03(\x0b\x32\x1d.yandex.cloud.video.v1.WidgetJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0c\"4\n\x19UpdateStylePresetMetadata\x12\x17\n\x0fstyle_preset_id\x18\x01 \x01(\t\"A\n\x18\x44\x65leteStylePresetRequest\x12%\n\x0fstyle_preset_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"4\n\x19\x44\x65leteStylePresetMetadata\x12\x17\n\x0fstyle_preset_id\x18\x01 \x01(\t2\xdf\x06\n\x12StylePresetService\x12\x89\x01\n\x03Get\x12,.yandex.cloud.video.v1.GetStylePresetRequest\x1a\".yandex.cloud.video.v1.StylePreset\"0\x82\xd3\xe4\x93\x02*\x12(/video/v1/stylePresets/{style_preset_id}\x12\x87\x01\n\x04List\x12..yandex.cloud.video.v1.ListStylePresetsRequest\x1a/.yandex.cloud.video.v1.ListStylePresetsResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/video/v1/stylePresets\x12\xab\x01\n\x06\x43reate\x12/.yandex.cloud.video.v1.CreateStylePresetRequest\x1a!.yandex.cloud.operation.Operation\"M\xb2\xd2*(\n\x19\x43reateStylePresetMetadata\x12\x0bStylePreset\x82\xd3\xe4\x93\x02\x1b\"\x16/video/v1/stylePresets:\x01*\x12\xbd\x01\n\x06Update\x12/.yandex.cloud.video.v1.UpdateStylePresetRequest\x1a!.yandex.cloud.operation.Operation\"_\xb2\xd2*(\n\x19UpdateStylePresetMetadata\x12\x0bStylePreset\x82\xd3\xe4\x93\x02-2(/video/v1/stylePresets/{style_preset_id}:\x01*\x12\xc4\x01\n\x06\x44\x65lete\x12/.yandex.cloud.video.v1.DeleteStylePresetRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*2\n\x19\x44\x65leteStylePresetMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02**(/video/v1/stylePresets/{style_preset_id}B\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.style_preset_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _globals['_GETSTYLEPRESETREQUEST'].fields_by_name['style_preset_id']._loaded_options = None
  _globals['_GETSTYLEPRESETREQUEST'].fields_by_name['style_preset_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTSTYLEPRESETSREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_LISTSTYLEPRESETSREQUEST'].fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTSTYLEPRESETSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSTYLEPRESETSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_LISTSTYLEPRESETSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSTYLEPRESETSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\007<=15000'
  _globals['_LISTSTYLEPRESETSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTSTYLEPRESETSREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTSTYLEPRESETSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTSTYLEPRESETSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['title']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['title']._serialized_options = b'\350\3071\001\362\3071\017[a-zA-Z0-9-_ ]+\212\3101\004<=50'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['background_color']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['background_color']._serialized_options = b'\350\3071\001\362\3071\r[#a-zA-Z0-9]+\212\3101\004<=50'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['widget_text_color_primary']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['widget_text_color_primary']._serialized_options = b'\350\3071\001\362\3071\r[#a-zA-Z0-9]+\212\3101\004<=50'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['widget_text_color_secondary']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['widget_text_color_secondary']._serialized_options = b'\350\3071\001\362\3071\r[#a-zA-Z0-9]+\212\3101\004<=50'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['widget_accent_color']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['widget_accent_color']._serialized_options = b'\350\3071\001\362\3071\r[#a-zA-Z0-9]+\212\3101\004<=50'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['widget_block_gap']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['widget_block_gap']._serialized_options = b'\372\3071\0040-10'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['widget_block_separator_color']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['widget_block_separator_color']._serialized_options = b'\350\3071\001\362\3071\r[#a-zA-Z0-9]+\212\3101\004<=50'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['player_border_radius']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['player_border_radius']._serialized_options = b'\372\3071\003>=0'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['player_color']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['player_color']._serialized_options = b'\350\3071\001\362\3071\r[#a-zA-Z0-9]+\212\3101\004<=50'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['playlist_selected_item_background_color']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['playlist_selected_item_background_color']._serialized_options = b'\350\3071\001\362\3071\r[#a-zA-Z0-9]+\212\3101\004<=50'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['playlist_item_border_radius']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['playlist_item_border_radius']._serialized_options = b'\372\3071\003>=0'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['playlist_item_gap']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['playlist_item_gap']._serialized_options = b'\372\3071\003>=0'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['playlist_location']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['playlist_location']._serialized_options = b'\350\3071\001'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['style_preset_id']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['style_preset_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['field_mask']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['field_mask']._serialized_options = b'\350\3071\001'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['title']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['title']._serialized_options = b'\362\3071\017[a-zA-Z0-9-_ ]*\212\3101\004<=50'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['background_color']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['background_color']._serialized_options = b'\362\3071\016[#a-zA-Z0-9-]*\212\3101\004<=50'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['widget_text_color_primary']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['widget_text_color_primary']._serialized_options = b'\362\3071\016[#a-zA-Z0-9-]*\212\3101\004<=50'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['widget_text_color_secondary']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['widget_text_color_secondary']._serialized_options = b'\362\3071\016[#a-zA-Z0-9-]*\212\3101\004<=50'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['widget_accent_color']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['widget_accent_color']._serialized_options = b'\362\3071\016[#a-zA-Z0-9-]*\212\3101\004<=50'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['widget_block_gap']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['widget_block_gap']._serialized_options = b'\372\3071\0040-10'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['widget_block_separator_color']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['widget_block_separator_color']._serialized_options = b'\362\3071\016[#a-zA-Z0-9-]*\212\3101\004<=50'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['player_border_radius']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['player_border_radius']._serialized_options = b'\372\3071\003>=0'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['player_color']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['player_color']._serialized_options = b'\362\3071\r[#a-zA-Z0-9]*\212\3101\004<=50'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['playlist_selected_item_background_color']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['playlist_selected_item_background_color']._serialized_options = b'\362\3071\r[#a-zA-Z0-9]*\212\3101\004<=50'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['playlist_item_border_radius']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['playlist_item_border_radius']._serialized_options = b'\372\3071\003>=0'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['playlist_item_gap']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['playlist_item_gap']._serialized_options = b'\372\3071\003>=0'
  _globals['_DELETESTYLEPRESETREQUEST'].fields_by_name['style_preset_id']._loaded_options = None
  _globals['_DELETESTYLEPRESETREQUEST'].fields_by_name['style_preset_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STYLEPRESETSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_STYLEPRESETSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002*\022(/video/v1/stylePresets/{style_preset_id}'
  _globals['_STYLEPRESETSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_STYLEPRESETSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\030\022\026/video/v1/stylePresets'
  _globals['_STYLEPRESETSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_STYLEPRESETSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*(\n\031CreateStylePresetMetadata\022\013StylePreset\202\323\344\223\002\033\"\026/video/v1/stylePresets:\001*'
  _globals['_STYLEPRESETSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_STYLEPRESETSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*(\n\031UpdateStylePresetMetadata\022\013StylePreset\202\323\344\223\002-2(/video/v1/stylePresets/{style_preset_id}:\001*'
  _globals['_STYLEPRESETSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_STYLEPRESETSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*2\n\031DeleteStylePresetMetadata\022\025google.protobuf.Empty\202\323\344\223\002**(/video/v1/stylePresets/{style_preset_id}'
  _globals['_GETSTYLEPRESETREQUEST']._serialized_start=286
  _globals['_GETSTYLEPRESETREQUEST']._serialized_end=348
  _globals['_LISTSTYLEPRESETSREQUEST']._serialized_start=351
  _globals['_LISTSTYLEPRESETSREQUEST']._serialized_end=535
  _globals['_LISTSTYLEPRESETSRESPONSE']._serialized_start=537
  _globals['_LISTSTYLEPRESETSRESPONSE']._serialized_end=653
  _globals['_CREATESTYLEPRESETREQUEST']._serialized_start=656
  _globals['_CREATESTYLEPRESETREQUEST']._serialized_end=1579
  _globals['_CREATESTYLEPRESETMETADATA']._serialized_start=1581
  _globals['_CREATESTYLEPRESETMETADATA']._serialized_end=1633
  _globals['_UPDATESTYLEPRESETREQUEST']._serialized_start=1636
  _globals['_UPDATESTYLEPRESETREQUEST']._serialized_end=2585
  _globals['_UPDATESTYLEPRESETMETADATA']._serialized_start=2587
  _globals['_UPDATESTYLEPRESETMETADATA']._serialized_end=2639
  _globals['_DELETESTYLEPRESETREQUEST']._serialized_start=2641
  _globals['_DELETESTYLEPRESETREQUEST']._serialized_end=2706
  _globals['_DELETESTYLEPRESETMETADATA']._serialized_start=2708
  _globals['_DELETESTYLEPRESETMETADATA']._serialized_end=2760
  _globals['_STYLEPRESETSERVICE']._serialized_start=2763
  _globals['_STYLEPRESETSERVICE']._serialized_end=3626
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/monitoring/v3/parametrization.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/monitoring/v3/parametrization.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.monitoring.v3 import unit_format_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_unit__format__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/monitoring/v3/parametrization.proto\x12\x1ayandex.cloud.monitoring.v3\x1a,yandex/cloud/monitoring/v3/unit_format.proto\"\x95\x01\n\x14LabelValuesParameter\x12\x13\n\tfolder_id\x18\x02 \x01(\tH\x00\x12\x11\n\tselectors\x18\x13 \x01(\t\x12\x11\n\tlabel_key\x18\x14 \x01(\t\x12\x17\n\x0fmultiselectable\x18\x15 \x01(\x08\x12\x16\n\x0e\x64\x65\x66\x61ult_values\x18\x16 \x03(\tB\x0b\n\tcontainerJ\x04\x08\x03\x10\x13\"R\n\x0f\x43ustomParameter\x12\x0e\n\x06values\x18\x01 \x03(\t\x12\x17\n\x0fmultiselectable\x18\x02 \x01(\x08\x12\x16\n\x0e\x64\x65\x66\x61ult_values\x18\x03 \x03(\t\"&\n\rTextParameter\x12\x15\n\rdefault_value\x18\x01 \x01(\t\"e\n\x0f\x44oubleParameter\x12\x15\n\rdefault_value\x18\x01 \x01(\x01\x12;\n\x0bunit_format\x18\x02 \x01(\x0e\x32&.yandex.cloud.monitoring.v3.UnitFormat\"f\n\x10IntegerParameter\x12\x15\n\rdefault_value\x18\x01 \x01(\x03\x12;\n\x0bunit_format\x18\x02 \x01(\x0e\x32&.yandex.cloud.monitoring.v3.UnitFormat\"-\n\x13TextValuesParameter\x12\x16\n\x0e\x64\x65\x66\x61ult_values\x18\x01 \x03(\t\"\xf5\x03\n\tParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12H\n\x0clabel_values\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.monitoring.v3.LabelValuesParameterH\x00\x12=\n\x06\x63ustom\x18\x04 \x01(\x0b\x32+.yandex.cloud.monitoring.v3.CustomParameterH\x00\x12\x39\n\x04text\x18\x05 \x01(\x0b\x32).yandex.cloud.monitoring.v3.TextParameterH\x00\x12I\n\x11integer_parameter\x18\x07 \x01(\x0b\x32,.yandex.cloud.monitoring.v3.IntegerParameterH\x00\x12G\n\x10\x64ouble_parameter\x18\x08 \x01(\x0b\x32+.yandex.cloud.monitoring.v3.DoubleParameterH\x00\x12\x46\n\x0btext_values\x18\t \x01(\x0b\x32/.yandex.cloud.monitoring.v3.TextValuesParameterH\x00\x12\x0e\n\x06hidden\x18\x06 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\tB\x06\n\x04\x64\x61ta\"_\n\x0fParametrization\x12\x39\n\nparameters\x18\x01 \x03(\x0b\x32%.yandex.cloud.monitoring.v3.Parameter\x12\x11\n\tselectors\x18\x02 \x01(\tBk\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.monitoring.v3.parametrization_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring'
  _globals['_LABELVALUESPARAMETER']._serialized_start=127
  _globals['_LABELVALUESPARAMETER']._serialized_end=276
  _globals['_CUSTOMPARAMETER']._serialized_start=278
  _globals['_CUSTOMPARAMETER']._serialized_end=360
  _globals['_TEXTPARAMETER']._serialized_start=362
  _globals['_TEXTPARAMETER']._serialized_end=400
  _globals['_DOUBLEPARAMETER']._serialized_start=402
  _globals['_DOUBLEPARAMETER']._serialized_end=503
  _globals['_INTEGERPARAMETER']._serialized_start=505
  _globals['_INTEGERPARAMETER']._serialized_end=607
  _globals['_TEXTVALUESPARAMETER']._serialized_start=609
  _globals['_TEXTVALUESPARAMETER']._serialized_end=654
  _globals['_PARAMETER']._serialized_start=657
  _globals['_PARAMETER']._serialized_end=1158
  _globals['_PARAMETRIZATION']._serialized_start=1160
  _globals['_PARAMETRIZATION']._serialized_end=1255
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.video.v1.stream_line_pb2
import yandex.cloud.video.v1.stream_line_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class StreamLineServiceStub:
    """Stream line management service.
    Provides methods for creating, retrieving, updating, and deleting stream lines,
    which define the technical configuration for receiving and processing video signals.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.GetStreamLineRequest,
        yandex.cloud.video.v1.stream_line_pb2.StreamLine,
    ]
    """Retrieves detailed information about a specific stream line by its ID.
    Returns all stream line metadata, configuration, and related information.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.ListStreamLinesRequest,
        yandex.cloud.video.v1.stream_line_service_pb2.ListStreamLinesResponse,
    ]
    """Lists all stream lines in a specific channel with pagination support.
    Results can be filtered and sorted using the provided parameters.
    """

    BatchGet: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.BatchGetStreamLinesRequest,
        yandex.cloud.video.v1.stream_line_service_pb2.BatchGetStreamLinesResponse,
    ]
    """Retrieves multiple stream lines by their IDs in a specific channel in a single request.
    This is more efficient than making multiple Get requests when retrieving several stream lines.
    """

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.CreateStreamLineRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new stream line in the specified channel with the provided configuration.
    Stream lines define the technical settings for receiving and processing video signals.
    """

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.UpdateStreamLineRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates an existing stream line's metadata and configuration.
    Only fields specified in the field_mask will be updated.
    """

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.DeleteStreamLineRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a specific stream line by its ID."""

    BatchDelete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.BatchDeleteStreamLinesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes multiple stream lines in a specific channel in a single request.
    This is more efficient than making multiple Delete requests when removing several stream lines.
    """

    PerformAction: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.PerformLineActionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Performs a specific action on a stream line, such as activation or deactivation.
    Actions change the stream line's state without modifying its configuration.
    """

    GetStreamKey: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.GetStreamKeyRequest,
        yandex.cloud.video.v1.stream_line_pb2.PushStreamKey,
    ]
    """Retrieves the unique stream key for a push-type stream line.
    This key is used to authenticate when pushing video streams to the platform.
    """

    UpdateStreamKey: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.UpdateStreamKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Regenerates and updates the stream key for a push-type stream line.
    This is useful for security purposes when the existing key may be compromised.
    """

class StreamLineServiceAsyncStub:
    """Stream line management service.
    Provides methods for creating, retrieving, updating, and deleting stream lines,
    which define the technical configuration for receiving and processing video signals.
    """

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.GetStreamLineRequest,
        yandex.cloud.video.v1.stream_line_pb2.StreamLine,
    ]
    """Retrieves detailed information about a specific stream line by its ID.
    Returns all stream line metadata, configuration, and related information.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.ListStreamLinesRequest,
        yandex.cloud.video.v1.stream_line_service_pb2.ListStreamLinesResponse,
    ]
    """Lists all stream lines in a specific channel with pagination support.
    Results can be filtered and sorted using the provided parameters.
    """

    BatchGet: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.BatchGetStreamLinesRequest,
        yandex.cloud.video.v1.stream_line_service_pb2.BatchGetStreamLinesResponse,
    ]
    """Retrieves multiple stream lines by their IDs in a specific channel in a single request.
    This is more efficient than making multiple Get requests when retrieving several stream lines.
    """

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.CreateStreamLineRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new stream line in the specified channel with the provided configuration.
    Stream lines define the technical settings for receiving and processing video signals.
    """

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.UpdateStreamLineRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates an existing stream line's metadata and configuration.
    Only fields specified in the field_mask will be updated.
    """

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.DeleteStreamLineRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a specific stream line by its ID."""

    BatchDelete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.BatchDeleteStreamLinesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes multiple stream lines in a specific channel in a single request.
    This is more efficient than making multiple Delete requests when removing several stream lines.
    """

    PerformAction: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.PerformLineActionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Performs a specific action on a stream line, such as activation or deactivation.
    Actions change the stream line's state without modifying its configuration.
    """

    GetStreamKey: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.GetStreamKeyRequest,
        yandex.cloud.video.v1.stream_line_pb2.PushStreamKey,
    ]
    """Retrieves the unique stream key for a push-type stream line.
    This key is used to authenticate when pushing video streams to the platform.
    """

    UpdateStreamKey: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.UpdateStreamKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Regenerates and updates the stream key for a push-type stream line.
    This is useful for security purposes when the existing key may be compromised.
    """

class StreamLineServiceServicer(metaclass=abc.ABCMeta):
    """Stream line management service.
    Provides methods for creating, retrieving, updating, and deleting stream lines,
    which define the technical configuration for receiving and processing video signals.
    """

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.video.v1.stream_line_service_pb2.GetStreamLineRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.stream_line_pb2.StreamLine, collections.abc.Awaitable[yandex.cloud.video.v1.stream_line_pb2.StreamLine]]:
        """Retrieves detailed information about a specific stream line by its ID.
        Returns all stream line metadata, configuration, and related information.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.video.v1.stream_line_service_pb2.ListStreamLinesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.stream_line_service_pb2.ListStreamLinesResponse, collections.abc.Awaitable[yandex.cloud.video.v1.stream_line_service_pb2.ListStreamLinesResponse]]:
        """Lists all stream lines in a specific channel with pagination support.
        Results can be filtered and sorted using the provided parameters.
        """

    @abc.abstractmethod
    def BatchGet(
        self,
        request: yandex.cloud.video.v1.stream_line_service_pb2.BatchGetStreamLinesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.stream_line_service_pb2.BatchGetStreamLinesResponse, collections.abc.Awaitable[yandex.cloud.video.v1.stream_line_service_pb2.BatchGetStreamLinesResponse]]:
        """Retrieves multiple stream lines by their IDs in a specific channel in a single request.
        This is more efficient than making multiple Get requests when retrieving several stream lines.
        """

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.video.v1.stream_line_service_pb2.CreateStreamLineRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a new stream line in the specified channel with the provided configuration.
        Stream lines define the technical settings for receiving and processing video signals.
        """

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.video.v1.stream_line_service_pb2.UpdateStreamLineRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates an existing stream line's metadata and configuration.
        Only fields specified in the field_mask will be updated.
        """

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.video.v1.stream_line_service_pb2.DeleteStreamLineRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes a specific stream line by its ID."""

    @abc.abstractmethod
    def BatchDelete(
        self,
        request: yandex.cloud.video.v1.stream_line_service_pb2.BatchDeleteStreamLinesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes multiple stream lines in a specific channel in a single request.
        This is more efficient than making multiple Delete requests when removing several stream lines.
        """

    @abc.abstractmethod
    def PerformAction(
        self,
        request: yandex.cloud.video.v1.stream_line_service_pb2.PerformLineActionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Performs a specific action on a stream line, such as activation or deactivation.
        Actions change the stream line's state without modifying its configuration.
        """

    @abc.abstractmethod
    def GetStreamKey(
        self,
        request: yandex.cloud.video.v1.stream_line_service_pb2.GetStreamKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.stream_line_pb2.PushStreamKey, collections.abc.Awaitable[yandex.cloud.video.v1.stream_line_pb2.PushStreamKey]]:
        """Retrieves the unique stream key for a push-type stream line.
        This key is used to authenticate when pushing video streams to the platform.
        """

    @abc.abstractmethod
    def UpdateStreamKey(
        self,
        request: yandex.cloud.video.v1.stream_line_service_pb2.UpdateStreamKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Regenerates and updates the stream key for a push-type stream line.
        This is useful for security purposes when the existing key may be compromised.
        """

def add_StreamLineServiceServicer_to_server(servicer: StreamLineServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/certificatemanager/v1/certificate.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/certificatemanager/v1/certificate.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/certificatemanager/v1/certificate.proto\x12\"yandex.cloud.certificatemanager.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xfa\x06\n\x0b\x43\x65rtificate\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12K\n\x06labels\x18\x06 \x03(\x0b\x32;.yandex.cloud.certificatemanager.v1.Certificate.LabelsEntry\x12\x41\n\x04type\x18\x07 \x01(\x0e\x32\x33.yandex.cloud.certificatemanager.v1.CertificateType\x12\x0f\n\x07\x64omains\x18\x08 \x03(\t\x12\x46\n\x06status\x18\t \x01(\x0e\x32\x36.yandex.cloud.certificatemanager.v1.Certificate.Status\x12\x0e\n\x06issuer\x18\n \x01(\t\x12\x0f\n\x07subject\x18\x0b \x01(\t\x12\x0e\n\x06serial\x18\x0c \x01(\t\x12.\n\nupdated_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tissued_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tnot_after\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nnot_before\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\nchallenges\x18\x11 \x03(\x0b\x32-.yandex.cloud.certificatemanager.v1.Challenge\x12\x1b\n\x13\x64\x65letion_protection\x18\x12 \x01(\x08\x12\x18\n\x10incomplete_chain\x18\x13 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"x\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0e\n\nVALIDATING\x10\x01\x12\x0b\n\x07INVALID\x10\x02\x12\n\n\x06ISSUED\x10\x03\x12\x0b\n\x07REVOKED\x10\x04\x12\x0c\n\x08RENEWING\x10\x05\x12\x12\n\x0eRENEWAL_FAILED\x10\x06\"\x8c\x05\n\tChallenge\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12?\n\x04type\x18\x02 \x01(\x0e\x32\x31.yandex.cloud.certificatemanager.v1.ChallengeType\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x44\n\x06status\x18\x05 \x01(\x0e\x32\x34.yandex.cloud.certificatemanager.v1.Challenge.Status\x12\x0f\n\x07message\x18\x06 \x01(\t\x12\r\n\x05\x65rror\x18\x07 \x01(\t\x12P\n\rdns_challenge\x18\x08 \x01(\x0b\x32\x37.yandex.cloud.certificatemanager.v1.Challenge.DnsRecordH\x00\x12P\n\x0ehttp_challenge\x18\t \x01(\x0b\x32\x36.yandex.cloud.certificatemanager.v1.Challenge.HttpFileH\x00\x1a\x36\n\tDnsRecord\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x1a(\n\x08HttpFile\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\"U\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0e\n\nPROCESSING\x10\x02\x12\t\n\x05VALID\x10\x03\x12\x0b\n\x07INVALID\x10\x04\x42\x0b\n\tchallenge\"]\n\x07Version\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0e\x63\x65rtificate_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp*N\n\x0f\x43\x65rtificateType\x12 \n\x1c\x43\x45RTIFICATE_TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08IMPORTED\x10\x01\x12\x0b\n\x07MANAGED\x10\x02*B\n\rChallengeType\x12\x1e\n\x1a\x43HALLENGE_TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03\x44NS\x10\x01\x12\x08\n\x04HTTP\x10\x02\x42\x83\x01\n&yandex.cloud.api.certificatemanager.v1ZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/certificatemanager/v1;certificatemanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.certificatemanager.v1.certificate_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&yandex.cloud.api.certificatemanager.v1ZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/certificatemanager/v1;certificatemanager'
  _globals['_CERTIFICATE_LABELSENTRY']._loaded_options = None
  _globals['_CERTIFICATE_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CERTIFICATETYPE']._serialized_start=1768
  _globals['_CERTIFICATETYPE']._serialized_end=1846
  _globals['_CHALLENGETYPE']._serialized_start=1848
  _globals['_CHALLENGETYPE']._serialized_end=1914
  _globals['_CERTIFICATE']._serialized_start=126
  _globals['_CERTIFICATE']._serialized_end=1016
  _globals['_CERTIFICATE_LABELSENTRY']._serialized_start=849
  _globals['_CERTIFICATE_LABELSENTRY']._serialized_end=894
  _globals['_CERTIFICATE_STATUS']._serialized_start=896
  _globals['_CERTIFICATE_STATUS']._serialized_end=1016
  _globals['_CHALLENGE']._serialized_start=1019
  _globals['_CHALLENGE']._serialized_end=1671
  _globals['_CHALLENGE_DNSRECORD']._serialized_start=1475
  _globals['_CHALLENGE_DNSRECORD']._serialized_end=1529
  _globals['_CHALLENGE_HTTPFILE']._serialized_start=1531
  _globals['_CHALLENGE_HTTPFILE']._serialized_end=1571
  _globals['_CHALLENGE_STATUS']._serialized_start=1573
  _globals['_CHALLENGE_STATUS']._serialized_end=1658
  _globals['_VERSION']._serialized_start=1673
  _globals['_VERSION']._serialized_end=1766
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.k8s.v1.node_group_pb2
import yandex.cloud.k8s.v1.node_group_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class NodeGroupServiceStub:
    """A set of methods for managing node groups."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.v1.node_group_service_pb2.GetNodeGroupRequest,
        yandex.cloud.k8s.v1.node_group_pb2.NodeGroup,
    ]
    """Returns the specified node group.

    To get the list of available node group, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.v1.node_group_service_pb2.ListNodeGroupsRequest,
        yandex.cloud.k8s.v1.node_group_service_pb2.ListNodeGroupsResponse,
    ]
    """Retrieves the list of node group in the specified Kubernetes cluster."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.v1.node_group_service_pb2.CreateNodeGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a node group in the specified Kubernetes cluster."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.v1.node_group_service_pb2.UpdateNodeGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified node group."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.v1.node_group_service_pb2.DeleteNodeGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified node group."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.v1.node_group_service_pb2.ListNodeGroupOperationsRequest,
        yandex.cloud.k8s.v1.node_group_service_pb2.ListNodeGroupOperationsResponse,
    ]
    """Lists operations for the specified node group."""

    ListNodes: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.v1.node_group_service_pb2.ListNodeGroupNodesRequest,
        yandex.cloud.k8s.v1.node_group_service_pb2.ListNodeGroupNodesResponse,
    ]
    """Retrieves the list of nodes in the specified Kubernetes cluster."""

class NodeGroupServiceAsyncStub:
    """A set of methods for managing node groups."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.v1.node_group_service_pb2.GetNodeGroupRequest,
        yandex.cloud.k8s.v1.node_group_pb2.NodeGroup,
    ]
    """Returns the specified node group.

    To get the list of available node group, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.v1.node_group_service_pb2.ListNodeGroupsRequest,
        yandex.cloud.k8s.v1.node_group_service_pb2.ListNodeGroupsResponse,
    ]
    """Retrieves the list of node group in the specified Kubernetes cluster."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.v1.node_group_service_pb2.CreateNodeGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a node group in the specified Kubernetes cluster."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.v1.node_group_service_pb2.UpdateNodeGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified node group."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.v1.node_group_service_pb2.DeleteNodeGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified node group."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.v1.node_group_service_pb2.ListNodeGroupOperationsRequest,
        yandex.cloud.k8s.v1.node_group_service_pb2.ListNodeGroupOperationsResponse,
    ]
    """Lists operations for the specified node group."""

    ListNodes: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.k8s.v1.node_group_service_pb2.ListNodeGroupNodesRequest,
        yandex.cloud.k8s.v1.node_group_service_pb2.ListNodeGroupNodesResponse,
    ]
    """Retrieves the list of nodes in the specified Kubernetes cluster."""

class NodeGroupServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing node groups."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.k8s.v1.node_group_service_pb2.GetNodeGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.k8s.v1.node_group_pb2.NodeGroup, collections.abc.Awaitable[yandex.cloud.k8s.v1.node_group_pb2.NodeGroup]]:
        """Returns the specified node group.

        To get the list of available node group, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.k8s.v1.node_group_service_pb2.ListNodeGroupsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.k8s.v1.node_group_service_pb2.ListNodeGroupsResponse, collections.abc.Awaitable[yandex.cloud.k8s.v1.node_group_service_pb2.ListNodeGroupsResponse]]:
        """Retrieves the list of node group in the specified Kubernetes cluster."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.k8s.v1.node_group_service_pb2.CreateNodeGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a node group in the specified Kubernetes cluster."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.k8s.v1.node_group_service_pb2.UpdateNodeGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified node group."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.k8s.v1.node_group_service_pb2.DeleteNodeGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified node group."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.k8s.v1.node_group_service_pb2.ListNodeGroupOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.k8s.v1.node_group_service_pb2.ListNodeGroupOperationsResponse, collections.abc.Awaitable[yandex.cloud.k8s.v1.node_group_service_pb2.ListNodeGroupOperationsResponse]]:
        """Lists operations for the specified node group."""

    @abc.abstractmethod
    def ListNodes(
        self,
        request: yandex.cloud.k8s.v1.node_group_service_pb2.ListNodeGroupNodesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.k8s.v1.node_group_service_pb2.ListNodeGroupNodesResponse, collections.abc.Awaitable[yandex.cloud.k8s.v1.node_group_service_pb2.ListNodeGroupNodesResponse]]:
        """Retrieves the list of nodes in the specified Kubernetes cluster."""

def add_NodeGroupServiceServicer_to_server(servicer: NodeGroupServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/foundation_models/v1/embedding/embedding_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/foundation_models/v1/embedding/embedding_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFyandex/cloud/ai/foundation_models/v1/embedding/embedding_service.proto\x12$yandex.cloud.ai.foundation_models.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\"a\n\x14TextEmbeddingRequest\x12\x11\n\tmodel_uri\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12(\n\x03\x64im\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"U\n\x15TextEmbeddingResponse\x12\x11\n\tembedding\x18\x01 \x03(\x01\x12\x12\n\nnum_tokens\x18\x02 \x01(\x03\x12\x15\n\rmodel_version\x18\x03 \x01(\t2\xcd\x01\n\x11\x45mbeddingsService\x12\xb7\x01\n\rTextEmbedding\x12:.yandex.cloud.ai.foundation_models.v1.TextEmbeddingRequest\x1a;.yandex.cloud.ai.foundation_models.v1.TextEmbeddingResponse\"-\x82\xd3\xe4\x93\x02\'\"\"/foundationModels/v1/textEmbedding:\x01*B\x90\x01\n(yandex.cloud.api.ai.foundation_models.v1Zdgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/foundation_models/v1/embedding;foundation_modelsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.foundation_models.v1.embedding.embedding_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.ai.foundation_models.v1Zdgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/foundation_models/v1/embedding;foundation_models'
  _globals['_EMBEDDINGSSERVICE'].methods_by_name['TextEmbedding']._loaded_options = None
  _globals['_EMBEDDINGSSERVICE'].methods_by_name['TextEmbedding']._serialized_options = b'\202\323\344\223\002\'\"\"/foundationModels/v1/textEmbedding:\001*'
  _globals['_TEXTEMBEDDINGREQUEST']._serialized_start=174
  _globals['_TEXTEMBEDDINGREQUEST']._serialized_end=271
  _globals['_TEXTEMBEDDINGRESPONSE']._serialized_start=273
  _globals['_TEXTEMBEDDINGRESPONSE']._serialized_end=358
  _globals['_EMBEDDINGSSERVICE']._serialized_start=361
  _globals['_EMBEDDINGSSERVICE']._serialized_end=566
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/stt/v3/stt_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/stt/v3/stt_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.stt.v3 import stt_pb2 as yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/ai/stt/v3/stt_service.proto\x12\x10speechkit.stt.v3\x1a yandex/cloud/ai/stt/v3/stt.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\";\n\x15GetRecognitionRequest\x12\"\n\x0coperation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=502q\n\nRecognizer\x12\x63\n\x12RecognizeStreaming\x12\".speechkit.stt.v3.StreamingRequest\x1a#.speechkit.stt.v3.StreamingResponse\"\x00(\x01\x30\x01\x32\xaf\x03\n\x0f\x41syncRecognizer\x12\x9c\x01\n\rRecognizeFile\x12&.speechkit.stt.v3.RecognizeFileRequest\x1a!.yandex.cloud.operation.Operation\"@\xb2\xd2*\x17\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1f\"\x1a/stt/v3/recognizeFileAsync:\x01*\x12\x80\x01\n\x0eGetRecognition\x12\'.speechkit.stt.v3.GetRecognitionRequest\x1a#.speechkit.stt.v3.StreamingResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/stt/v3/getRecognition0\x01\x12z\n\x11\x44\x65leteRecognition\x12*.speechkit.stt.v3.DeleteRecognitionRequest\x1a\x16.google.protobuf.Empty\"!\x82\xd3\xe4\x93\x02\x1b*\x19/stt/v3/deleteRecognitionB\\\n\x1ayandex.cloud.api.ai.stt.v3Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/stt/v3;sttb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.stt.v3.stt_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032yandex.cloud.api.ai.stt.v3Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/stt/v3;stt'
  _globals['_GETRECOGNITIONREQUEST'].fields_by_name['operation_id']._loaded_options = None
  _globals['_GETRECOGNITIONREQUEST'].fields_by_name['operation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ASYNCRECOGNIZER'].methods_by_name['RecognizeFile']._loaded_options = None
  _globals['_ASYNCRECOGNIZER'].methods_by_name['RecognizeFile']._serialized_options = b'\262\322*\027\022\025google.protobuf.Empty\202\323\344\223\002\037\"\032/stt/v3/recognizeFileAsync:\001*'
  _globals['_ASYNCRECOGNIZER'].methods_by_name['GetRecognition']._loaded_options = None
  _globals['_ASYNCRECOGNIZER'].methods_by_name['GetRecognition']._serialized_options = b'\202\323\344\223\002\030\022\026/stt/v3/getRecognition'
  _globals['_ASYNCRECOGNIZER'].methods_by_name['DeleteRecognition']._loaded_options = None
  _globals['_ASYNCRECOGNIZER'].methods_by_name['DeleteRecognition']._serialized_options = b'\202\323\344\223\002\033*\031/stt/v3/deleteRecognition'
  _globals['_GETRECOGNITIONREQUEST']._serialized_start=260
  _globals['_GETRECOGNITIONREQUEST']._serialized_end=319
  _globals['_RECOGNIZER']._serialized_start=321
  _globals['_RECOGNIZER']._serialized_end=434
  _globals['_ASYNCRECOGNIZER']._serialized_start=437
  _globals['_ASYNCRECOGNIZER']._serialized_end=868
# @@protoc_insertion_point(module_scope)
